@@ -5,6 +5,9 @@
 
 import logging
 import socket
+from typing import Optional
+
+from ops import Container
 
 logger = logging.getLogger()
 
@@ -27,3 +30,15 @@ def get_app_hostname(app_name: str, model_name: str) -> str:
     dns_name_parts = hostname_parts[hostname_parts.index("svc") :]
     dns_name = ".".join(dns_name_parts)  # 'svc.cluster.local'
     return f"{app_name}.{model_name}.{dns_name}"  # 'app.model.svc.cluster.local'
+
+
+def get_litmus_version(container: Container) -> Optional[str]:
+    """Get the running litmus version."""
+    if not container.can_connect():
+        return None
+
+    version_file_path = "/VERSION"
+    if not container.exists(version_file_path):
+        logger.warning("Version file not found at %s", version_file_path)
+        return None
+    return container.pull(version_file_path, encoding="utf-8").read()
